==> qcad-3.32.4.0-2-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_th.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="th_TH">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_th.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="th_TH">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>แนวตั้ง/แนวนอน</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>ย้อนกลับ</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>กำหนดเอง</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>ตาราง</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>จุดปลาย</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>บนวัตถุ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>ตั้งฉาก</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>สัมผัส</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>จุดศูนย์กลาง</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>จุดกึ่งกลาง</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>จุดตัด</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>จุดอ้างอิง</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>ระยะทาง</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>ไม่ถูกต้อง</translation>
    </message>
</context>
</TS>
